Quantcast

- Now clear hostile units on combat end

Kith [01-16-17 - 22:18]
- Now clear hostile units on combat end
- Added Havoc (Warlock) to Unique Target data
Filename
Ellipsis/AuraData.lua
Ellipsis/Control.lua
Ellipsis/Ellipsis.toc
Ellipsis_Options/Ellipsis_Options.toc
diff --git a/Ellipsis/AuraData.lua b/Ellipsis/AuraData.lua
index eae1299..e1101e9 100644
--- a/Ellipsis/AuraData.lua
+++ b/Ellipsis/AuraData.lua
@@ -101,6 +101,7 @@ local dataUniqueAuras = {
 	[211015]	= true,	-- Hex (Cockroach)
 	-- WARLOCK
 	[710]		= true,	-- Banish
+	[80240]		= true, -- Havoc
 	[118699]	= true,	-- Fear
 }

diff --git a/Ellipsis/Ellipsis.toc b/Ellipsis/Ellipsis.toc
index 8926cb1..8729727 100644
--- a/Ellipsis/Ellipsis.toc
+++ b/Ellipsis/Ellipsis.toc
@@ -2,7 +2,7 @@
 ## Title: Ellipsis (|cff67b1e9K|cff4779ceith|cff67b1e9M|cff4779ceod|r)
 ## Notes: A full-featured, multi-target Aura (DoTs and HoTs) tracker.
 ## Author: Kith
-## Version: 4.2.4
+## Version: 4.2.5
 ## SavedVariables: EllipsisDB, EllipsisVersion
 ## OptionalDeps: Ace3, LibSharedMedia-3.0, LibSink-2.0
 ## X-Embeds: Ace3, LibSharedMedia-3.0, LibSink-2.0
diff --git a/Ellipsis_Options/Ellipsis_Options.toc b/Ellipsis_Options/Ellipsis_Options.toc
index 15a2f87..2fb96bc 100644
--- a/Ellipsis_Options/Ellipsis_Options.toc
+++ b/Ellipsis_Options/Ellipsis_Options.toc
@@ -2,7 +2,7 @@
 ## Title: Ellipsis Options (|cff67b1e9K|cff4779ceith|cff67b1e9M|cff4779ceod|r)
 ## Notes: Options for Ellipsis. Must be enabled to alter settings.
 ## Author: Kith
-## Version: 4.2.4
+## Version: 4.2.5
 ## RequiredDeps: Ellipsis
 ## OptionalDeps: Ace3
 ## LoadOnDemand: 1
diff --git a/Ellipsis/Control.lua b/Ellipsis/Control.lua
index b5d7045..419e06d 100644
--- a/Ellipsis/Control.lua
+++ b/Ellipsis/Control.lua
@@ -241,7 +241,7 @@ end
 -- PLAYER_REGEN_ENABLED
 -- ------------------------
 function Ellipsis:PLAYER_REGEN_ENABLED()
-	local ageCheck = time() - 600 -- cleanse entries older than 10 minutes
+	local ageCheck = time() - 600 -- cleanse entries older than 10 minutes so we don't end up with a huge table of (now useless) entries

 	for guid, timestamp in pairs(blacklistByGUID) do
 		if (timestamp < ageCheck) then
@@ -252,6 +252,13 @@ function Ellipsis:PLAYER_REGEN_ENABLED()
 	if (totemID < -10000) then
 		totemID = -1 -- prevent our 'fake totem' spellID from getting out of hand if it ever gets this high
 	end
+
+	-- remove all unit data for hostile targets on combat end (either reset or dead), used for Absolute Corruption mostly
+	for _, unit in pairs(activeUnits) do
+		if (unit.unitHostile) then -- hostile mob, no longer in combat, so no longer relevant
+			unit:Release()
+		end
+	end
 end

